@@ -207,23 +207,32 @@ class dyn_vec:
             self.parent_rf.ob.keyframe_insert(data_path='scale', frame=cur_frame)
 
 class anim_text:
-    def __init__(self, name, data, label, fix_place, if_str, anim):
+    def __init__(self, name, parent, anim):
+
+        self.anim = anim
+
         bpy.data.curves.new(type="FONT", name="Font Curve").body = "INIT"
         font_obj = bpy.data.objects.new(name=name+'_text', object_data=bpy.data.curves["Font Curve"])
         bpy.context.scene.collection.objects.link(font_obj)
 
+        self.obj = bpy.data.objects[name+'_text']
+
+        self.obj.parent = parent
+
+
+    def animate(data, label, fix_place, if_str)
         if not(if_str):
             def update(self):
-                text = bpy.data.objects[name+'_text']
+                text = self.obj
                 cur_frame = bpy.context.scene.frame_current
                 
-                if np.any(cur_frame == anim.frames):
+                if np.any(cur_frame == self.anim.frames):
                     ind = np.where(cur_frame == anim.frames)[0][0]
                     text.data.body = ('{0:.'+str(fix_place)+'f}').format(data[ind]) + ' ' + label
                     
         else:
             def update(self):
-                text = bpy.data.objects[name+'_text']
+                text = self.obj
                 cur_frame = bpy.context.scene.frame_current
                 
                 if np.any(cur_frame == anim.frames):
